@@ -9,6 +9,8 @@ from evmspec.structs.transaction import (
     TransactionLegacy,
     Transaction1559,
     Transaction2930,
+    Transaction4844,
+    Transaction7702,
 )
 
 __all__ = [
@@ -28,4 +30,6 @@ __all__ = [
     "TransactionLegacy",
     "Transaction2930",
     "Transaction1559",
+    "Transaction4844",
+    "Transaction7702",
 ]
